@@ -1,5 +1,7 @@
 import os
 import numpy as np
+import audioread
+import librosa
 from mido import MidiFile
 
 from .piano_vad import (note_detection_with_onset_offset_regress, 
@@ -489,4 +491,71 @@ class RegressionPostProcessor(object):
                 'onset_time': pedal_on_offs[i, 0], 
                 'offset_time': pedal_on_offs[i, 1]})
         
-        return pedal_events
\ No newline at end of file
+        return pedal_events
+
+
+def load_audio(path, sr=22050, mono=True, offset=0.0, duration=None,
+    dtype=np.float32, res_type='kaiser_best', 
+    backends=[audioread.ffdec.FFmpegAudioFile]):
+    """Load audio. The only difference with librosa.core.load() is that, ffmpeg
+    backend is always used in this function. While librosa.core.load() use Macca
+    backend as default on MACs"""
+
+    y = []
+    with audioread.audio_open(os.path.realpath(path), backends=backends) as input_file:
+        sr_native = input_file.samplerate
+        n_channels = input_file.channels
+
+        s_start = int(np.round(sr_native * offset)) * n_channels
+
+        if duration is None:
+            s_end = np.inf
+        else:
+            s_end = s_start + (int(np.round(sr_native * duration))
+                               * n_channels)
+
+        n = 0
+
+        for frame in input_file:
+            frame = librosa.core.audio.util.buf_to_float(frame, dtype=dtype)
+            n_prev = n
+            n = n + len(frame)
+
+            if n < s_start:
+                # offset is after the current frame
+                # keep reading
+                continue
+
+            if s_end < n_prev:
+                # we're off the end.  stop reading
+                break
+
+            if s_end < n:
+                # the end is in this frame.  crop.
+                frame = frame[:s_end - n_prev]
+
+            if n_prev <= s_start <= n:
+                # beginning is in this frame
+                frame = frame[(s_start - n_prev):]
+
+            # tack on the current frame
+            y.append(frame)
+
+    if y:
+        y = np.concatenate(y)
+
+        if n_channels > 1:
+            y = y.reshape((-1, n_channels)).T
+            if mono:
+                y = to_mono(y)
+
+        if sr is not None:
+            y = librosa.core.audio.resample(y, sr_native, sr, res_type=res_type)
+
+        else:
+            sr = sr_native
+
+    # Final cleanup for dtype and contiguity
+    y = np.ascontiguousarray(y, dtype=dtype)
+
+    return (y, sr)
\ No newline at end of file
